@@ -23,6 +23,7 @@ import zc.monitor.interfaces
 
 INTERACTIVE_MARKER = object()
 QUIT_MARKER = object()
+MORE_MARKER = object()
 
 class Server:
 
@@ -36,7 +37,9 @@ class Server:
 
     def handle_input(self, connection, data):
         args = data.strip().split()
-        if not args:
+        if self.mode is MORE_MARKER:
+            command_name = self.last_command[0]
+        elif not args:
             if self.last_command is not None:
                 command_name, args = self.last_command
             else:
@@ -57,9 +60,7 @@ class Server:
                 traceback.print_exc(100, connection)
                 print >> connection, "%s: %s\n" % (v.__class__.__name__, v)
             else:
-                if res is INTERACTIVE_MARKER:
-                    self.mode = res
-                elif res is QUIT_MARKER:
+                if res in (INTERACTIVE_MARKER, QUIT_MARKER, MORE_MARKER):
                     self.mode = res
 
         if self.mode is QUIT_MARKER:
@@ -83,7 +84,7 @@ def start(port):
             # Don't kill the process just because somebody else has our port.
             # This might be a zopectl debug or some other innocuous problem.
             logging.warning(
-                'unable to start z3monitor server because port %d is in use.',
+                'unable to start zc.monitor server because port %d is in use.',
                 port)
             return False
         else:
